@@ -81,7 +81,7 @@ class BPMService:
         ret = self.send(address, headers, body)
         if 'body' in ret:
             if 'succeeded' in ret['body']:
-                if not ret['succeeded']:
+                if not ret['body']['succeeded']:
                     raise ServiceError(ret['body'])
             if 'reply' in ret['body']:
                 return ret['body']['reply']
