@@ -11,6 +11,25 @@ class Service:
         self.bpm = bpm
 
     def sendMail(self, msg: dict):
+        """
+        Envía un email desde el backend de BPM.
+
+        Es mensaje es un dict con el contenido del mensaje. Tiene los siguientes atributos:
+        - from:str = el remitente
+        - to:[str] = destinatarios
+        - cc:[str] = con copia
+        - bcc:[str] = con copia oculta
+        - subject:str = asunto
+        - message:str = cuerpo del mensaje. Se interpreta como html si comienza con < y termina con >
+        - resource:str = cuerpo del mensaje en un archivo (si message está vacío)
+        - deleteAfterSend:bool = eliminar el mensaje del servidor luego de enviarlo
+        - headers:dict = cabeceras del mail (RFC822)
+        - images:dict = imágenes incrustadas en el mail {"cid":"recurso"}
+        - attachments:dict = archivos adjuntos en el mail {"nombre":"recurso"}
+
+        :param msg: el mensaje en forma de dict
+        :return:
+        """
         return self.bpm.call("EBHBPMService.sendMail", msg)
 
     def execute(self, script: str, context: dict):
